@@ -874,7 +874,7 @@ def _copy_object(context, bucket, source_file, destination_file):
 
     response = yield _get_object(context, context.s3_bucket, source_file)
     file_bytes = response['Body'].read()
-    response = yield _save_any(context, None, file_bytes, _key(context, destination_file), 'notebook', None)
+    response = yield _save_any(context, None, file_bytes, destination_file, 'notebook', None)
     return response
     # return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
 
